Index: tests/gclient_test.py |
diff --git a/tests/gclient_test.py b/tests/gclient_test.py |
index 0d5b235a7c6e15541b2925812a876b9520b53ef5..aff9174e167757c896be49855bf630e432c6ecfc 100755 |
--- a/tests/gclient_test.py |
+++ b/tests/gclient_test.py |
@@ -660,11 +660,11 @@ class GclientTest(trial_dir.TestCase): |
], |
self._get_processed()) |
- def testRecurselistOverride(self): |
- """Verifies gclient respects the |recurselist| var syntax. |
+ def testRecursedepsOverride(self): |
+ """Verifies gclient respects the |recursedeps| var syntax. |
This is what we mean to check here: |
- - |recurselist| = [...] on 2 levels means we pull exactly 3 deps |
+ - |recursedeps| = {...} on 2 levels means we pull exactly 3 deps |
(up to /fizz, but not /fuzz) |
- pulling foo/bar with no recursion (in .gclient) is overriden by |
a later pull of foo/bar with recursion (in the dep tree) |
@@ -683,13 +683,13 @@ class GclientTest(trial_dir.TestCase): |
'deps = {\n' |
' "bar": "/bar",\n' |
'}\n' |
- 'recurselist = ["bar"]') |
+ 'recursedeps = {"bar"}') |
iannucci
2014/07/03 18:55:59
Note that the {'foo'} syntax is actually python 2.
|
write( |
os.path.join('bar', 'DEPS'), |
'deps = {\n' |
' "baz": "/baz",\n' |
'}\n' |
- 'recurselist = ["baz"]') |
+ 'recursedeps = {"baz"}') |
write( |
os.path.join('baz', 'DEPS'), |
'deps = {\n' |
@@ -720,37 +720,37 @@ class GclientTest(trial_dir.TestCase): |
], |
self._get_processed()) |
- def testRecursionOverridesRecurselist(self): |
- """Verifies gclient respects |recursion| over |recurselist|. |
+ def testRecursionOverridesRecursedeps(self): |
+ """Verifies gclient respects |recursion| over |recursedeps|. |
|recursion| is set in a top-level DEPS file. That value is meant |
to affect how many subdeps are parsed via recursion. |
- |recurselist| is set in each DEPS file to control whether or not |
+ |recursedeps| is set in each DEPS file to control whether or not |
to recurse into the immediate next subdep. |
This test verifies that if both syntaxes are mixed in a DEPS file, |
we disable |recurselist| support and only obey |recursion|. |
Since this setting is evaluated per DEPS file, recursed DEPS |
files will each be re-evaluated according to the per DEPS rules. |
So a DEPS that only contains |recurselist| could then override any |
previous |recursion| setting. There is extra processing to ensure |
this does not happen. |
For this test to work correctly, we need to use a DEPS chain that |
only contains recursion controls in the top DEPS file. |
- In foo, |recursion| and |recurselist| are specified. When we see |
- |recursion|, we stop trying to use |recurselist|. |
+ In foo, |recursion| and |recursedeps| are specified. When we see |
+ |recursion|, we stop trying to use |recursedeps|. |
There are 2 constructions of DEPS here that are key to this test: |
- (1) In foo, if we used |recurselist| instead of |recursion|, we |
+ (1) In foo, if we used |recursedeps| instead of |recursion|, we |
would also pull in bar. Since bar's DEPS doesn't contain any |
recursion statements, we would stop processing at bar. |
- (2) In fizz, if we used |recurselist| at all, we should pull in |
+ (2) In fizz, if we used |recursedeps| at all, we should pull in |
fuzz. |
We expect to keep going past bar (satisfying 1) and we don't |
@@ -768,7 +768,7 @@ class GclientTest(trial_dir.TestCase): |
' "bar": "/bar",\n' |
'}\n' |
'recursion = 3\n' |
- 'recurselist = ["bar"]') |
+ 'recursedeps = {"bar"}') |
write( |
os.path.join('bar', 'DEPS'), |
'deps = {\n' |
@@ -784,7 +784,7 @@ class GclientTest(trial_dir.TestCase): |
'deps = {\n' |
' "fuzz": "/fuzz",\n' |
'}\n' |
- 'recurselist = ["fuzz"]') |
+ 'recursedeps = {"fuzz"}') |
write( |
os.path.join('fuzz', 'DEPS'), |
'deps = {\n' |
@@ -800,11 +800,11 @@ class GclientTest(trial_dir.TestCase): |
'svn://example.com/bar', |
'svn://example.com/foo/bar', |
# Deps after this would have been skipped if we were obeying |
- # |recurselist|. |
+ # |recursedeps|. |
'svn://example.com/foo/bar/baz', |
'svn://example.com/foo/bar/baz/fizz', |
# And this dep would have been picked up if we were obeying |
- # |recurselist|. |
+ # |recursedeps|. |
# 'svn://example.com/foo/bar/baz/fuzz', |
], |
self._get_processed()) |
@@ -720,37 +720,37 @@ class GclientTest(trial_dir.TestCase): |
to recurse into the immediate next subdep. |
This test verifies that if both syntaxes are mixed in a DEPS file, |
- we disable |recurselist| support and only obey |recursion|. |
+ we disable |recursedeps| support and only obey |recursion|. |
Since this setting is evaluated per DEPS file, recursed DEPS |
files will each be re-evaluated according to the per DEPS rules. |
@@ -720,37 +720,37 @@ class GclientTest(trial_dir.TestCase): |
Since this setting is evaluated per DEPS file, recursed DEPS |
files will each be re-evaluated according to the per DEPS rules. |
- So a DEPS that only contains |recurselist| could then override any |
+ So a DEPS that only contains |recursedeps| could then override any |
previous |recursion| setting. There is extra processing to ensure |
this does not happen. |